PO4A-HEADER: mode=after; position=^\[\[contributors\]\]; beginboundary=\[\[
[[translation]]
*Tłumaczenie*

//Translators put your names below here in the addendum file
Kerusey Karyu <keruseykaryu@o2.pl>, 2014-2019.

